==> resource_planner-0.2.1.gem: app/assets/javascripts/resource_planner/index_fullcalendar.js <==
$(document).ready(function() {

  var initialLocaleCode = 'en';
  var events = [];

  // // Fetch our events
  // $.ajax({
  //   url: "http://localhost:3000/resource_planner/events.json",
  //   method: "GET",
  //   datatype: "json",
  //   data: {
  //     "$where" : "start_date_time > '" + moment().subtract(31, 'days').format("YYYY-MM-DDT00:00:00") + "'",
  //     "city" : "Portland",
  //     "$order" : "start_date_time DESC",
  //   }
  // }).done(function(response) {
  //   // Parse our events into an event object for FullCalendar
  //   $.each(response, function(idx, e) {
  //     events.push({
  //       start: e.start_at.toISOString(),
  //       end: e.end_at.toISOString(),
  //       title: e.name,
  //       url: e.web_link,
  //     });
  //   });
  // });

  $('#fullcalendar_calendar').fullCalendar({
  schedulerLicenseKey: 'CC-Attribution-NonCommercial-NoDerivatives',
  header: {
      left: 'prev,next today',
      center: 'title',
      right: 'month,agendaWeek,agendaDay,listWeek',
    },
    defaultDate: Date(),
    navLinks: true, // can click day/week names to navigate views
    aspectRatio: 3.0,
    firstDay: 0,
    weekNumbers: true,
    weekNumbersWithinDays: true,
    weekNumberCalculation: 'ISO',
    editable: true,
    allDay: true,
    eventSources: [
      '/resource_planner/events.json',
      //'/feed2.php',
    ],
    //events: events,
    //eventDataTransform: function(rawEventData) {
    //  return {
    //      id: rawEventData.id,
    //      title: rawEventData.name,
    //      start: rawEventData.start_at,
    //      end: rawEventData.end_at,
    //  };
    //},
    eventLimit: true, // allow "more" link when too many events
    eventDrop: function(event, delta, revertFunc) {
      $('#start_date').val(event.start.format());
    }
  });

  // $('#fullcalendar_calendar').fullCalendar({
  //   schedulerLicenseKey: 'CC-Attribution-NonCommercial-NoDerivatives',
  //   now: '2018-09-06',
  //   editable: true, // enable draggable events
  //   aspectRatio: 1.8,
  //   scrollTime: '00:00', // undo default 6am scrollTime
  //   header: {
  //     left: 'promptTrainer promptRoom today prev,next',
  //     center: 'title',
  //     right: ''
  //   },
  //   customButtons: {
  //     promptTrainer: {
  //       text: '+ trainer',
  //       click: function() {
  //         var title = prompt('Trainer name');
  //         if (title) {
  //           $('#fullcalendar_calendar').fullCalendar(
  //             'addResource',
  //             { title: title },
  //             true // scroll to the new resource?
  //           );
  //         }
  //       }
  //     },
  //     promptRoom: {
  //       text: '+ room',
  //       click: function() {
  //         var title = prompt('Room name');
  //         if (title) {
  //           $('#fullcalendar_calendar').fullCalendar(
  //             'addResource',
  //             { title: title },
  //             true // scroll to the new resource?
  //           );
  //         }
  //       }
  //     }
  //   },
  //   defaultView: 'timelineDay',
  //   views: {
  //     timelineThreeDays: {
  //       type: 'timeline',
  //       duration: { days: 3 }
  //     }
  //   },
  //   resourceGroupField: 'resourceType',
  //   //resourceLabelText: 'Rooms',
  //   resources: [
  //     { id: 'a', resourceType: 'Trainer', title: 'Resource 1' },
  //     { id: 'b', resourceType: 'Trainer', title: 'Resource 2' },
  //     { id: 'c', resourceType: 'Trainer', title: 'Resource 3' },
  //     { id: 'd', resourceType: 'Trainer', title: 'Resource 4' },
  //     { id: 'e', resourceType: 'Room', title: 'Resource 5' },
  //     { id: 'f', resourceType: 'Room', title: 'Resource 6' },
  //     { id: 'g', resourceType: 'Room', title: 'Resource 7' },
  //     { id: 'h', resourceType: 'Room', title: 'Resource 8' },
  //     { id: 'i', resourceType: 'Equipment', title: 'Resource 9' },
  //     { id: 'j', resourceType: 'Equipment', title: 'Resource 10' }
  //   ],
  //   events: [
  //     { id: '1', resourceIds: ['b', 'e'], start: '2018-09-06T02:00:00', end: '2018-09-06T07:00:00', title: 'event 1' },
  //     { id: '2', resourceId: 'c', start: '2018-04-07T05:00:00', end: '2018-04-07T22:00:00', title: 'event 2' },
  //     { id: '3', resourceId: 'd', start: '2018-04-06', end: '2018-04-08', title: 'event 3' },
  //     { id: '4', resourceId: 'e', start: '2018-04-07T03:00:00', end: '2018-04-07T08:00:00', title: 'event 4' },
  //     { id: '5', resourceId: 'f', start: '2018-04-07T00:30:00', end: '2018-04-07T02:30:00', title: 'event 5' }
  //   ]
  // });

  // build the locale selector's options
  $.each($.fullCalendar.locales, function(localeCode) {
    $('#locale-selector').append(
      $('<option/>')
        .attr('value', localeCode)
        .prop('selected', localeCode == initialLocaleCode)
        .text(localeCode)
    );
  });

  // when the selected option changes, dynamically change the calendar option
  $('#locale-selector').on('change', function() {
    if (this.value) {
      $('#fullcalendar_calendar').fullCalendar('option', 'locale', this.value);
    }
  });

});

==> resource_planner-0.2.9.gem: app/assets/javascripts/resource_planner/index_fullcalendar.js <==
$(document).ready(function () {

  var initialLocaleCode = 'en-gb';
  var now = new Date().setMinutes(0);
  var events = [];

  // // Fetch our events
  // $.ajax({
  //   url: "http://localhost:3000/resource_planner/events.json",
  //   method: "GET",
  //   datatype: "json",
  //   data: {
  //     "$where" : "start_date_time > '" + moment().subtract(31, 'days').format("YYYY-MM-DDT00:00:00") + "'",
  //     "city" : "Portland",
  //     "$order" : "start_date_time DESC",
  //   }
  // }).done(function(response) {
  //   // Parse our events into an event object for FullCalendar
  //   $.each(response, function(idx, e) {
  //     events.push({
  //       start: e.start_at.toISOString(),
  //       end: e.end_at.toISOString(),
  //       title: e.name,
  //       url: e.web_link,
  //     });
  //   });
  // });

  var calendarEl = document.getElementById('fullcalendar_calendar');
  var calendar = new FullCalendar.Calendar(calendarEl, {
    schedulerLicenseKey: 'GPL-My-Project-Is-Open-Source',
    plugins: ['interaction', 'dayGrid', 'timeGrid', 'list', 'rrule'],
    defaultView: 'dayGridMonth',
    header: {
      left: 'prev,next today',
      center: 'title',
      right: 'dayGridMonth, timeGridWeek, dayGridDay, listWeek',
    },
    defaultDate: now,
    timeZone: 'local',
    navLinks: true, // can click day/week names to navigate views
    aspectRatio: 3.0,
    firstDay: 0,
    weekNumbers: true,
    weekNumbersWithinDays: true,
    weekNumberCalculation: 'ISO',
    editable: true,
    allDay: true,
    eventSources: [
      '/resource_planner/events.json',
    ],
    eventLimit: true, // allow "more" link when too many events
  });

  calendar.render();

  // $('#fullcalendar_calendar').fullCalendar({
  //   schedulerLicenseKey: 'CC-Attribution-NonCommercial-NoDerivatives',
  //   now: '2018-09-06',
  //   editable: true, // enable draggable events
  //   aspectRatio: 1.8,
  //   scrollTime: '00:00', // undo default 6am scrollTime
  //   header: {
  //     left: 'promptTrainer promptRoom today prev,next',
  //     center: 'title',
  //     right: ''
  //   },
  //   customButtons: {
  //     promptTrainer: {
  //       text: '+ trainer',
  //       click: function() {
  //         var title = prompt('Trainer name');
  //         if (title) {
  //           $('#fullcalendar_calendar').fullCalendar(
  //             'addResource',
  //             { title: title },
  //             true // scroll to the new resource?
  //           );
  //         }
  //       }
  //     },
  //     promptRoom: {
  //       text: '+ room',
  //       click: function() {
  //         var title = prompt('Room name');
  //         if (title) {
  //           $('#fullcalendar_calendar').fullCalendar(
  //             'addResource',
  //             { title: title },
  //             true // scroll to the new resource?
  //           );
  //         }
  //       }
  //     }
  //   },
  //   defaultView: 'timelineDay',
  //   views: {
  //     timelineThreeDays: {
  //       type: 'timeline',
  //       duration: { days: 3 }
  //     }
  //   },
  //   resourceGroupField: 'resourceType',
  //   //resourceLabelText: 'Rooms',
  //   resources: [
  //     { id: 'a', resourceType: 'Trainer', title: 'Resource 1' },
  //     { id: 'b', resourceType: 'Trainer', title: 'Resource 2' },
  //     { id: 'c', resourceType: 'Trainer', title: 'Resource 3' },
  //     { id: 'd', resourceType: 'Trainer', title: 'Resource 4' },
  //     { id: 'e', resourceType: 'Room', title: 'Resource 5' },
  //     { id: 'f', resourceType: 'Room', title: 'Resource 6' },
  //     { id: 'g', resourceType: 'Room', title: 'Resource 7' },
  //     { id: 'h', resourceType: 'Room', title: 'Resource 8' },
  //     { id: 'i', resourceType: 'Equipment', title: 'Resource 9' },
  //     { id: 'j', resourceType: 'Equipment', title: 'Resource 10' }
  //   ],
  //   events: [
  //     { id: '1', resourceIds: ['b', 'e'], start: '2018-09-06T02:00:00', end: '2018-09-06T07:00:00', title: 'event 1' },
  //     { id: '2', resourceId: 'c', start: '2018-04-07T05:00:00', end: '2018-04-07T22:00:00', title: 'event 2' },
  //     { id: '3', resourceId: 'd', start: '2018-04-06', end: '2018-04-08', title: 'event 3' },
  //     { id: '4', resourceId: 'e', start: '2018-04-07T03:00:00', end: '2018-04-07T08:00:00', title: 'event 4' },
  //     { id: '5', resourceId: 'f', start: '2018-04-07T00:30:00', end: '2018-04-07T02:30:00', title: 'event 5' }
  //   ]
  // });

  // build the locale selector's options
  $.each(FullCalendarLocalesAll, function (locale) {
    $('#locale-selector').append(
      $('<option/>')
        .attr('value', FullCalendarLocalesAll[locale].code)
        .prop('selected', FullCalendarLocalesAll[locale].code == initialLocaleCode)
        .text(FullCalendarLocalesAll[locale].code)
    );
  });

  // // when the selected option changes, dynamically change the calendar option
  $('#locale-selector').on('change', function () {
    if (this.value) {
      calendar.setOption('locale', this.value);
    }
  });

});
